%PDF- %PDF-
| Direktori : /usr/share/doc/libapr1-dev/html/ |
| Current File : //usr/share/doc/libapr1-dev/html/apr__global__mutex_8h_source.html |
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "https://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="en-US">
<head>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=11"/>
<meta name="generator" content="Doxygen 1.9.8"/>
<meta name="viewport" content="width=device-width, initial-scale=1"/>
<title>Apache Portable Runtime: apr_global_mutex.h Source File</title>
<link href="tabs.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="jquery.js"></script>
<script type="text/javascript" src="dynsections.js"></script>
<link href="search/search.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="search/searchdata.js"></script>
<script type="text/javascript" src="search/search.js"></script>
<link href="doxygen.css" rel="stylesheet" type="text/css" />
</head>
<body>
<div id="top"><!-- do not remove this div, it is closed by doxygen! -->
<div id="titlearea">
<table cellspacing="0" cellpadding="0">
<tbody>
<tr id="projectrow">
<td id="projectalign">
<div id="projectname">Apache Portable Runtime
</div>
</td>
</tr>
</tbody>
</table>
</div>
<!-- end header part -->
<!-- Generated by Doxygen 1.9.8 -->
<script type="text/javascript">
/* @license magnet:?xt=urn:btih:d3d9a9a6595521f9666a5e94cc830dab83b65699&dn=expat.txt MIT */
var searchBox = new SearchBox("searchBox", "search/",'.html');
/* @license-end */
</script>
<script type="text/javascript" src="menudata.js"></script>
<script type="text/javascript" src="menu.js"></script>
<script type="text/javascript">
/* @license magnet:?xt=urn:btih:d3d9a9a6595521f9666a5e94cc830dab83b65699&dn=expat.txt MIT */
$(function() {
initMenu('',true,false,'search.php','Search');
$(document).ready(function() { init_search(); });
});
/* @license-end */
</script>
<div id="main-nav"></div>
<script type="text/javascript">
/* @license magnet:?xt=urn:btih:d3d9a9a6595521f9666a5e94cc830dab83b65699&dn=expat.txt MIT */
$(document).ready(function() { init_codefold(0); });
/* @license-end */
</script>
<!-- window showing the filter options -->
<div id="MSearchSelectWindow"
onmouseover="return searchBox.OnSearchSelectShow()"
onmouseout="return searchBox.OnSearchSelectHide()"
onkeydown="return searchBox.OnSearchSelectKey(event)">
</div>
<!-- iframe showing the search results (closed by default) -->
<div id="MSearchResultsWindow">
<div id="MSearchResults">
<div class="SRPage">
<div id="SRIndex">
<div id="SRResults"></div>
<div class="SRStatus" id="Loading">Loading...</div>
<div class="SRStatus" id="Searching">Searching...</div>
<div class="SRStatus" id="NoMatches">No Matches</div>
</div>
</div>
</div>
</div>
<div id="nav-path" class="navpath">
<ul>
<li class="navelem"><a class="el" href="dir_d44c64559bbebec7f509842c48db8b23.html">include</a></li> </ul>
</div>
</div><!-- top -->
<div class="header">
<div class="headertitle"><div class="title">apr_global_mutex.h</div></div>
</div><!--header-->
<div class="contents">
<a href="apr__global__mutex_8h.html">Go to the documentation of this file.</a><div class="fragment"><div class="line"><a id="l00001" name="l00001"></a><span class="lineno"> 1</span><span class="comment">/* Licensed to the Apache Software Foundation (ASF) under one or more</span></div>
<div class="line"><a id="l00002" name="l00002"></a><span class="lineno"> 2</span><span class="comment"> * contributor license agreements. See the NOTICE file distributed with</span></div>
<div class="line"><a id="l00003" name="l00003"></a><span class="lineno"> 3</span><span class="comment"> * this work for additional information regarding copyright ownership.</span></div>
<div class="line"><a id="l00004" name="l00004"></a><span class="lineno"> 4</span><span class="comment"> * The ASF licenses this file to You under the Apache License, Version 2.0</span></div>
<div class="line"><a id="l00005" name="l00005"></a><span class="lineno"> 5</span><span class="comment"> * (the "License"); you may not use this file except in compliance with</span></div>
<div class="line"><a id="l00006" name="l00006"></a><span class="lineno"> 6</span><span class="comment"> * the License. You may obtain a copy of the License at</span></div>
<div class="line"><a id="l00007" name="l00007"></a><span class="lineno"> 7</span><span class="comment"> *</span></div>
<div class="line"><a id="l00008" name="l00008"></a><span class="lineno"> 8</span><span class="comment"> * http://www.apache.org/licenses/LICENSE-2.0</span></div>
<div class="line"><a id="l00009" name="l00009"></a><span class="lineno"> 9</span><span class="comment"> *</span></div>
<div class="line"><a id="l00010" name="l00010"></a><span class="lineno"> 10</span><span class="comment"> * Unless required by applicable law or agreed to in writing, software</span></div>
<div class="line"><a id="l00011" name="l00011"></a><span class="lineno"> 11</span><span class="comment"> * distributed under the License is distributed on an "AS IS" BASIS,</span></div>
<div class="line"><a id="l00012" name="l00012"></a><span class="lineno"> 12</span><span class="comment"> * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.</span></div>
<div class="line"><a id="l00013" name="l00013"></a><span class="lineno"> 13</span><span class="comment"> * See the License for the specific language governing permissions and</span></div>
<div class="line"><a id="l00014" name="l00014"></a><span class="lineno"> 14</span><span class="comment"> * limitations under the License.</span></div>
<div class="line"><a id="l00015" name="l00015"></a><span class="lineno"> 15</span><span class="comment"> */</span></div>
<div class="line"><a id="l00016" name="l00016"></a><span class="lineno"> 16</span> </div>
<div class="line"><a id="l00017" name="l00017"></a><span class="lineno"> 17</span><span class="preprocessor">#ifndef APR_GLOBAL_MUTEX_H</span></div>
<div class="line"><a id="l00018" name="l00018"></a><span class="lineno"> 18</span><span class="preprocessor">#define APR_GLOBAL_MUTEX_H</span></div>
<div class="line"><a id="l00019" name="l00019"></a><span class="lineno"> 19</span><span class="comment"></span> </div>
<div class="line"><a id="l00020" name="l00020"></a><span class="lineno"> 20</span><span class="comment">/**</span></div>
<div class="line"><a id="l00021" name="l00021"></a><span class="lineno"> 21</span><span class="comment"> * @file apr_global_mutex.h</span></div>
<div class="line"><a id="l00022" name="l00022"></a><span class="lineno"> 22</span><span class="comment"> * @brief APR Global Locking Routines</span></div>
<div class="line"><a id="l00023" name="l00023"></a><span class="lineno"> 23</span><span class="comment"> */</span></div>
<div class="line"><a id="l00024" name="l00024"></a><span class="lineno"> 24</span> </div>
<div class="line"><a id="l00025" name="l00025"></a><span class="lineno"> 25</span><span class="preprocessor">#include "<a class="code" href="apr_8h.html">apr.h</a>"</span></div>
<div class="line"><a id="l00026" name="l00026"></a><span class="lineno"> 26</span><span class="preprocessor">#include "<a class="code" href="apr__proc__mutex_8h.html">apr_proc_mutex.h</a>"</span> <span class="comment">/* only for apr_lockmech_e */</span></div>
<div class="line"><a id="l00027" name="l00027"></a><span class="lineno"> 27</span><span class="preprocessor">#include "<a class="code" href="apr__pools_8h.html">apr_pools.h</a>"</span></div>
<div class="line"><a id="l00028" name="l00028"></a><span class="lineno"> 28</span><span class="preprocessor">#include "<a class="code" href="apr__errno_8h.html">apr_errno.h</a>"</span></div>
<div class="line"><a id="l00029" name="l00029"></a><span class="lineno"> 29</span><span class="preprocessor">#if APR_PROC_MUTEX_IS_GLOBAL</span></div>
<div class="line"><a id="l00030" name="l00030"></a><span class="lineno"> 30</span><span class="preprocessor">#include "<a class="code" href="apr__proc__mutex_8h.html">apr_proc_mutex.h</a>"</span></div>
<div class="line"><a id="l00031" name="l00031"></a><span class="lineno"> 31</span><span class="preprocessor">#endif</span></div>
<div class="line"><a id="l00032" name="l00032"></a><span class="lineno"> 32</span><span class="preprocessor">#include "<a class="code" href="apr__time_8h.html">apr_time.h</a>"</span></div>
<div class="line"><a id="l00033" name="l00033"></a><span class="lineno"> 33</span> </div>
<div class="line"><a id="l00034" name="l00034"></a><span class="lineno"> 34</span><span class="preprocessor">#ifdef __cplusplus</span></div>
<div class="line"><a id="l00035" name="l00035"></a><span class="lineno"> 35</span><span class="keyword">extern</span> <span class="stringliteral">"C"</span> {</div>
<div class="line"><a id="l00036" name="l00036"></a><span class="lineno"> 36</span><span class="preprocessor">#endif </span><span class="comment">/* __cplusplus */</span><span class="preprocessor"></span></div>
<div class="line"><a id="l00037" name="l00037"></a><span class="lineno"> 37</span><span class="comment"></span> </div>
<div class="line"><a id="l00038" name="l00038"></a><span class="lineno"> 38</span><span class="comment">/**</span></div>
<div class="line"><a id="l00039" name="l00039"></a><span class="lineno"> 39</span><span class="comment"> * @defgroup APR_GlobalMutex Global Locking Routines</span></div>
<div class="line"><a id="l00040" name="l00040"></a><span class="lineno"> 40</span><span class="comment"> * @ingroup APR </span></div>
<div class="line"><a id="l00041" name="l00041"></a><span class="lineno"> 41</span><span class="comment"> * @{</span></div>
<div class="line"><a id="l00042" name="l00042"></a><span class="lineno"> 42</span><span class="comment"> */</span></div>
<div class="line"><a id="l00043" name="l00043"></a><span class="lineno"> 43</span> </div>
<div class="line"><a id="l00044" name="l00044"></a><span class="lineno"> 44</span><span class="preprocessor">#if !APR_PROC_MUTEX_IS_GLOBAL || defined(DOXYGEN)</span></div>
<div class="line"><a id="l00045" name="l00045"></a><span class="lineno"> 45</span><span class="comment"></span> </div>
<div class="line"><a id="l00046" name="l00046"></a><span class="lineno"> 46</span><span class="comment">/** Opaque global mutex structure. */</span></div>
<div class="line"><a id="l00047" name="l00047"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7"> 47</a></span><span class="keyword">typedef</span> <span class="keyword">struct </span><a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> <a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a>;</div>
<div class="line"><a id="l00048" name="l00048"></a><span class="lineno"> 48</span> </div>
<div class="line"><a id="l00049" name="l00049"></a><span class="lineno"> 49</span><span class="comment">/* Function definitions */</span></div>
<div class="line"><a id="l00050" name="l00050"></a><span class="lineno"> 50</span><span class="comment"></span> </div>
<div class="line"><a id="l00051" name="l00051"></a><span class="lineno"> 51</span><span class="comment">/**</span></div>
<div class="line"><a id="l00052" name="l00052"></a><span class="lineno"> 52</span><span class="comment"> * Create and initialize a mutex that can be used to synchronize both</span></div>
<div class="line"><a id="l00053" name="l00053"></a><span class="lineno"> 53</span><span class="comment"> * processes and threads. Note: There is considerable overhead in using</span></div>
<div class="line"><a id="l00054" name="l00054"></a><span class="lineno"> 54</span><span class="comment"> * this API if only cross-process or cross-thread mutual exclusion is</span></div>
<div class="line"><a id="l00055" name="l00055"></a><span class="lineno"> 55</span><span class="comment"> * required. See apr_proc_mutex.h and apr_thread_mutex.h for more</span></div>
<div class="line"><a id="l00056" name="l00056"></a><span class="lineno"> 56</span><span class="comment"> * specialized lock routines.</span></div>
<div class="line"><a id="l00057" name="l00057"></a><span class="lineno"> 57</span><span class="comment"> * @param mutex the memory address where the newly created mutex will be</span></div>
<div class="line"><a id="l00058" name="l00058"></a><span class="lineno"> 58</span><span class="comment"> * stored.</span></div>
<div class="line"><a id="l00059" name="l00059"></a><span class="lineno"> 59</span><span class="comment"> * @param fname A file name to use if the lock mechanism requires one. This</span></div>
<div class="line"><a id="l00060" name="l00060"></a><span class="lineno"> 60</span><span class="comment"> * argument should always be provided. The lock code itself will</span></div>
<div class="line"><a id="l00061" name="l00061"></a><span class="lineno"> 61</span><span class="comment"> * determine if it should be used.</span></div>
<div class="line"><a id="l00062" name="l00062"></a><span class="lineno"> 62</span><span class="comment"> * @param mech The mechanism to use for the interprocess lock, if any; one of</span></div>
<div class="line"><a id="l00063" name="l00063"></a><span class="lineno"> 63</span><span class="comment"> * <PRE></span></div>
<div class="line"><a id="l00064" name="l00064"></a><span class="lineno"> 64</span><span class="comment"> * APR_LOCK_FCNTL</span></div>
<div class="line"><a id="l00065" name="l00065"></a><span class="lineno"> 65</span><span class="comment"> * APR_LOCK_FLOCK</span></div>
<div class="line"><a id="l00066" name="l00066"></a><span class="lineno"> 66</span><span class="comment"> * APR_LOCK_SYSVSEM</span></div>
<div class="line"><a id="l00067" name="l00067"></a><span class="lineno"> 67</span><span class="comment"> * APR_LOCK_POSIXSEM</span></div>
<div class="line"><a id="l00068" name="l00068"></a><span class="lineno"> 68</span><span class="comment"> * APR_LOCK_PROC_PTHREAD</span></div>
<div class="line"><a id="l00069" name="l00069"></a><span class="lineno"> 69</span><span class="comment"> * APR_LOCK_DEFAULT pick the default mechanism for the platform</span></div>
<div class="line"><a id="l00070" name="l00070"></a><span class="lineno"> 70</span><span class="comment"> * APR_LOCK_DEFAULT_TIMED pick the default timed mechanism</span></div>
<div class="line"><a id="l00071" name="l00071"></a><span class="lineno"> 71</span><span class="comment"> * </PRE></span></div>
<div class="line"><a id="l00072" name="l00072"></a><span class="lineno"> 72</span><span class="comment"> * @param pool the pool from which to allocate the mutex.</span></div>
<div class="line"><a id="l00073" name="l00073"></a><span class="lineno"> 73</span><span class="comment"> * @warning Check APR_HAS_foo_SERIALIZE defines to see if the platform supports</span></div>
<div class="line"><a id="l00074" name="l00074"></a><span class="lineno"> 74</span><span class="comment"> * APR_LOCK_foo. Only APR_LOCK_DEFAULT is portable.</span></div>
<div class="line"><a id="l00075" name="l00075"></a><span class="lineno"> 75</span><span class="comment"> */</span></div>
<div class="line"><a id="l00076" name="l00076"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga7a5ade1ba8ea6c7a7a61e3e719683cb0"> 76</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<a class="code hl_typedef" href="group__apr__errno.html#gaf76ee4543247e9fb3f3546203e590a6c">apr_status_t</a>) <a class="code hl_function" href="group___a_p_r___global_mutex.html#ga7a5ade1ba8ea6c7a7a61e3e719683cb0">apr_global_mutex_create</a>(<a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> **mutex,</div>
<div class="line"><a id="l00077" name="l00077"></a><span class="lineno"> 77</span> <span class="keyword">const</span> <span class="keywordtype">char</span> *fname,</div>
<div class="line"><a id="l00078" name="l00078"></a><span class="lineno"> 78</span> <a class="code hl_enumeration" href="group__apr__proc__mutex.html#ga75dd95a48a1e855a87b509b522746ed4">apr_lockmech_e</a> mech,</div>
<div class="line"><a id="l00079" name="l00079"></a><span class="lineno"> 79</span> <a class="code hl_typedef" href="group__apr__pools.html#gaf137f28edcf9a086cd6bc36c20d7cdfb">apr_pool_t</a> *pool);</div>
<div class="line"><a id="l00080" name="l00080"></a><span class="lineno"> 80</span><span class="comment"></span> </div>
<div class="line"><a id="l00081" name="l00081"></a><span class="lineno"> 81</span><span class="comment">/**</span></div>
<div class="line"><a id="l00082" name="l00082"></a><span class="lineno"> 82</span><span class="comment"> * Re-open a mutex in a child process.</span></div>
<div class="line"><a id="l00083" name="l00083"></a><span class="lineno"> 83</span><span class="comment"> * @param mutex The newly re-opened mutex structure.</span></div>
<div class="line"><a id="l00084" name="l00084"></a><span class="lineno"> 84</span><span class="comment"> * @param fname A file name to use if the mutex mechanism requires one. This</span></div>
<div class="line"><a id="l00085" name="l00085"></a><span class="lineno"> 85</span><span class="comment"> * argument should always be provided. The mutex code itself will</span></div>
<div class="line"><a id="l00086" name="l00086"></a><span class="lineno"> 86</span><span class="comment"> * determine if it should be used. This filename should be the </span></div>
<div class="line"><a id="l00087" name="l00087"></a><span class="lineno"> 87</span><span class="comment"> * same one that was passed to apr_global_mutex_create().</span></div>
<div class="line"><a id="l00088" name="l00088"></a><span class="lineno"> 88</span><span class="comment"> * @param pool The pool to operate on.</span></div>
<div class="line"><a id="l00089" name="l00089"></a><span class="lineno"> 89</span><span class="comment"> * @remark This function must be called to maintain portability, even</span></div>
<div class="line"><a id="l00090" name="l00090"></a><span class="lineno"> 90</span><span class="comment"> * if the underlying lock mechanism does not require it.</span></div>
<div class="line"><a id="l00091" name="l00091"></a><span class="lineno"> 91</span><span class="comment"> */</span></div>
<div class="line"><a id="l00092" name="l00092"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga51eb034bca0352075c92c08a21d4d7a0"> 92</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<a class="code hl_typedef" href="group__apr__errno.html#gaf76ee4543247e9fb3f3546203e590a6c">apr_status_t</a>) <a class="code hl_function" href="group___a_p_r___global_mutex.html#ga51eb034bca0352075c92c08a21d4d7a0">apr_global_mutex_child_init</a>(</div>
<div class="line"><a id="l00093" name="l00093"></a><span class="lineno"> 93</span> <a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> **mutex,</div>
<div class="line"><a id="l00094" name="l00094"></a><span class="lineno"> 94</span> <span class="keyword">const</span> <span class="keywordtype">char</span> *fname,</div>
<div class="line"><a id="l00095" name="l00095"></a><span class="lineno"> 95</span> <a class="code hl_typedef" href="group__apr__pools.html#gaf137f28edcf9a086cd6bc36c20d7cdfb">apr_pool_t</a> *pool);</div>
<div class="line"><a id="l00096" name="l00096"></a><span class="lineno"> 96</span><span class="comment"></span> </div>
<div class="line"><a id="l00097" name="l00097"></a><span class="lineno"> 97</span><span class="comment">/**</span></div>
<div class="line"><a id="l00098" name="l00098"></a><span class="lineno"> 98</span><span class="comment"> * Acquire the lock for the given mutex. If the mutex is already locked,</span></div>
<div class="line"><a id="l00099" name="l00099"></a><span class="lineno"> 99</span><span class="comment"> * the current thread will be put to sleep until the lock becomes available.</span></div>
<div class="line"><a id="l00100" name="l00100"></a><span class="lineno"> 100</span><span class="comment"> * @param mutex the mutex on which to acquire the lock.</span></div>
<div class="line"><a id="l00101" name="l00101"></a><span class="lineno"> 101</span><span class="comment"> */</span></div>
<div class="line"><a id="l00102" name="l00102"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga1338485664e6c2737340114cace57121"> 102</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<a class="code hl_typedef" href="group__apr__errno.html#gaf76ee4543247e9fb3f3546203e590a6c">apr_status_t</a>) <a class="code hl_function" href="group___a_p_r___global_mutex.html#ga1338485664e6c2737340114cace57121">apr_global_mutex_lock</a>(<a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> *mutex);</div>
<div class="line"><a id="l00103" name="l00103"></a><span class="lineno"> 103</span><span class="comment"></span> </div>
<div class="line"><a id="l00104" name="l00104"></a><span class="lineno"> 104</span><span class="comment">/**</span></div>
<div class="line"><a id="l00105" name="l00105"></a><span class="lineno"> 105</span><span class="comment"> * Attempt to acquire the lock for the given mutex. If the mutex has already</span></div>
<div class="line"><a id="l00106" name="l00106"></a><span class="lineno"> 106</span><span class="comment"> * been acquired, the call returns immediately with APR_EBUSY. Note: it</span></div>
<div class="line"><a id="l00107" name="l00107"></a><span class="lineno"> 107</span><span class="comment"> * is important that the APR_STATUS_IS_EBUSY(s) macro be used to determine</span></div>
<div class="line"><a id="l00108" name="l00108"></a><span class="lineno"> 108</span><span class="comment"> * if the return value was APR_EBUSY, for portability reasons.</span></div>
<div class="line"><a id="l00109" name="l00109"></a><span class="lineno"> 109</span><span class="comment"> * @param mutex the mutex on which to attempt the lock acquiring.</span></div>
<div class="line"><a id="l00110" name="l00110"></a><span class="lineno"> 110</span><span class="comment"> */</span></div>
<div class="line"><a id="l00111" name="l00111"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga2a6543fba6473b47e33a7b7fc2ba6935"> 111</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<a class="code hl_typedef" href="group__apr__errno.html#gaf76ee4543247e9fb3f3546203e590a6c">apr_status_t</a>) <a class="code hl_function" href="group___a_p_r___global_mutex.html#ga2a6543fba6473b47e33a7b7fc2ba6935">apr_global_mutex_trylock</a>(<a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> *mutex);</div>
<div class="line"><a id="l00112" name="l00112"></a><span class="lineno"> 112</span><span class="comment"></span> </div>
<div class="line"><a id="l00113" name="l00113"></a><span class="lineno"> 113</span><span class="comment">/**</span></div>
<div class="line"><a id="l00114" name="l00114"></a><span class="lineno"> 114</span><span class="comment"> * Attempt to acquire the lock for the given mutex until timeout expires.</span></div>
<div class="line"><a id="l00115" name="l00115"></a><span class="lineno"> 115</span><span class="comment"> * If the acquisition time outs, the call returns with APR_TIMEUP.</span></div>
<div class="line"><a id="l00116" name="l00116"></a><span class="lineno"> 116</span><span class="comment"> * @param mutex the mutex on which to attempt the lock acquiring.</span></div>
<div class="line"><a id="l00117" name="l00117"></a><span class="lineno"> 117</span><span class="comment"> * @param timeout the relative timeout (microseconds).</span></div>
<div class="line"><a id="l00118" name="l00118"></a><span class="lineno"> 118</span><span class="comment"> * @note A negative or nul timeout means immediate attempt, returning</span></div>
<div class="line"><a id="l00119" name="l00119"></a><span class="lineno"> 119</span><span class="comment"> * APR_TIMEUP without blocking if it the lock is already acquired.</span></div>
<div class="line"><a id="l00120" name="l00120"></a><span class="lineno"> 120</span><span class="comment"> */</span></div>
<div class="line"><a id="l00121" name="l00121"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#gae4d4ae9454c19bc58c56b69f42edfe8a"> 121</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<a class="code hl_typedef" href="group__apr__errno.html#gaf76ee4543247e9fb3f3546203e590a6c">apr_status_t</a>) <a class="code hl_function" href="group___a_p_r___global_mutex.html#gae4d4ae9454c19bc58c56b69f42edfe8a">apr_global_mutex_timedlock</a>(<a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> *mutex,</div>
<div class="line"><a id="l00122" name="l00122"></a><span class="lineno"> 122</span> <a class="code hl_typedef" href="group__apr__time.html#gaae2129185a395cc393f76fabf4f43e47">apr_interval_time_t</a> timeout);</div>
<div class="line"><a id="l00123" name="l00123"></a><span class="lineno"> 123</span><span class="comment"></span> </div>
<div class="line"><a id="l00124" name="l00124"></a><span class="lineno"> 124</span><span class="comment">/**</span></div>
<div class="line"><a id="l00125" name="l00125"></a><span class="lineno"> 125</span><span class="comment"> * Release the lock for the given mutex.</span></div>
<div class="line"><a id="l00126" name="l00126"></a><span class="lineno"> 126</span><span class="comment"> * @param mutex the mutex from which to release the lock.</span></div>
<div class="line"><a id="l00127" name="l00127"></a><span class="lineno"> 127</span><span class="comment"> */</span></div>
<div class="line"><a id="l00128" name="l00128"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga16e732ae76dfe104b157e0fc543d3aa3"> 128</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<a class="code hl_typedef" href="group__apr__errno.html#gaf76ee4543247e9fb3f3546203e590a6c">apr_status_t</a>) <a class="code hl_function" href="group___a_p_r___global_mutex.html#ga16e732ae76dfe104b157e0fc543d3aa3">apr_global_mutex_unlock</a>(<a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> *mutex);</div>
<div class="line"><a id="l00129" name="l00129"></a><span class="lineno"> 129</span><span class="comment"></span> </div>
<div class="line"><a id="l00130" name="l00130"></a><span class="lineno"> 130</span><span class="comment">/**</span></div>
<div class="line"><a id="l00131" name="l00131"></a><span class="lineno"> 131</span><span class="comment"> * Destroy the mutex and free the memory associated with the lock.</span></div>
<div class="line"><a id="l00132" name="l00132"></a><span class="lineno"> 132</span><span class="comment"> * @param mutex the mutex to destroy.</span></div>
<div class="line"><a id="l00133" name="l00133"></a><span class="lineno"> 133</span><span class="comment"> */</span></div>
<div class="line"><a id="l00134" name="l00134"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga1f2cb4a1ec57089db49701e747892607"> 134</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<a class="code hl_typedef" href="group__apr__errno.html#gaf76ee4543247e9fb3f3546203e590a6c">apr_status_t</a>) <a class="code hl_function" href="group___a_p_r___global_mutex.html#ga1f2cb4a1ec57089db49701e747892607">apr_global_mutex_destroy</a>(<a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> *mutex);</div>
<div class="line"><a id="l00135" name="l00135"></a><span class="lineno"> 135</span><span class="comment"></span> </div>
<div class="line"><a id="l00136" name="l00136"></a><span class="lineno"> 136</span><span class="comment">/**</span></div>
<div class="line"><a id="l00137" name="l00137"></a><span class="lineno"> 137</span><span class="comment"> * Return the name of the lockfile for the mutex, or NULL</span></div>
<div class="line"><a id="l00138" name="l00138"></a><span class="lineno"> 138</span><span class="comment"> * if the mutex doesn't use a lock file</span></div>
<div class="line"><a id="l00139" name="l00139"></a><span class="lineno"> 139</span><span class="comment"> */</span></div>
<div class="line"><a id="l00140" name="l00140"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#gabaecd41419208b84ae3b3b6fe402f51e"> 140</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<span class="keyword">const</span> <span class="keywordtype">char</span> *) <a class="code hl_function" href="group___a_p_r___global_mutex.html#gabaecd41419208b84ae3b3b6fe402f51e">apr_global_mutex_lockfile</a>(<a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> *mutex);</div>
<div class="line"><a id="l00141" name="l00141"></a><span class="lineno"> 141</span><span class="comment"></span> </div>
<div class="line"><a id="l00142" name="l00142"></a><span class="lineno"> 142</span><span class="comment">/**</span></div>
<div class="line"><a id="l00143" name="l00143"></a><span class="lineno"> 143</span><span class="comment"> * Get the mechanism of the mutex, as it relates to the actual method</span></div>
<div class="line"><a id="l00144" name="l00144"></a><span class="lineno"> 144</span><span class="comment"> * used for the underlying apr_proc_mutex_t.</span></div>
<div class="line"><a id="l00145" name="l00145"></a><span class="lineno"> 145</span><span class="comment"> * @param mutex the mutex to get the mechanism from.</span></div>
<div class="line"><a id="l00146" name="l00146"></a><span class="lineno"> 146</span><span class="comment"> */</span></div>
<div class="line"><a id="l00147" name="l00147"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga812b48b7afac2976a148fd16f4ede2de"> 147</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<a class="code hl_enumeration" href="group__apr__proc__mutex.html#ga75dd95a48a1e855a87b509b522746ed4">apr_lockmech_e</a>) <a class="code hl_function" href="group___a_p_r___global_mutex.html#ga812b48b7afac2976a148fd16f4ede2de">apr_global_mutex_mech</a>(<a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> *mutex);</div>
<div class="line"><a id="l00148" name="l00148"></a><span class="lineno"> 148</span><span class="comment"></span> </div>
<div class="line"><a id="l00149" name="l00149"></a><span class="lineno"> 149</span><span class="comment">/**</span></div>
<div class="line"><a id="l00150" name="l00150"></a><span class="lineno"> 150</span><span class="comment"> * Get the mechanism's name of the mutex, as it relates to the actual method</span></div>
<div class="line"><a id="l00151" name="l00151"></a><span class="lineno"> 151</span><span class="comment"> * used for the underlying apr_proc_mutex_t.</span></div>
<div class="line"><a id="l00152" name="l00152"></a><span class="lineno"> 152</span><span class="comment"> * @param mutex the mutex to get the mechanism's name from.</span></div>
<div class="line"><a id="l00153" name="l00153"></a><span class="lineno"> 153</span><span class="comment"> */</span></div>
<div class="line"><a id="l00154" name="l00154"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#gaef62790d34a253c63bb2e8bbe5a6a802"> 154</a></span><a class="code hl_define" href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a>(<span class="keyword">const</span> <span class="keywordtype">char</span> *) <a class="code hl_function" href="group___a_p_r___global_mutex.html#gaef62790d34a253c63bb2e8bbe5a6a802">apr_global_mutex_name</a>(<a class="code hl_typedef" href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a> *mutex);</div>
<div class="line"><a id="l00155" name="l00155"></a><span class="lineno"> 155</span><span class="comment"></span> </div>
<div class="line"><a id="l00156" name="l00156"></a><span class="lineno"> 156</span><span class="comment">/**</span></div>
<div class="line"><a id="l00157" name="l00157"></a><span class="lineno"> 157</span><span class="comment"> * Set mutex permissions.</span></div>
<div class="line"><a id="l00158" name="l00158"></a><span class="lineno"> 158</span><span class="comment"> */</span></div>
<div class="line"><a id="l00159" name="l00159"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga09b08568c41cec184cf2f4915ecc04e9"> 159</a></span>APR_PERMS_SET_IMPLEMENT(global_mutex);</div>
<div class="line"><a id="l00160" name="l00160"></a><span class="lineno"> 160</span><span class="comment"></span> </div>
<div class="line"><a id="l00161" name="l00161"></a><span class="lineno"> 161</span><span class="comment">/**</span></div>
<div class="line"><a id="l00162" name="l00162"></a><span class="lineno"> 162</span><span class="comment"> * Get the pool used by this global_mutex.</span></div>
<div class="line"><a id="l00163" name="l00163"></a><span class="lineno"> 163</span><span class="comment"> * @return apr_pool_t the pool</span></div>
<div class="line"><a id="l00164" name="l00164"></a><span class="lineno"> 164</span><span class="comment"> */</span></div>
<div class="line"><a id="l00165" name="l00165"></a><span class="lineno"><a class="line" href="group___a_p_r___global_mutex.html#ga1697401b37b26bf46ddb2fe186f33a7f"> 165</a></span><a class="code hl_define" href="group__apr__pools.html#ga89ce1d55c7f0c39ea87c88eabd655394">APR_POOL_DECLARE_ACCESSOR</a>(global_mutex);</div>
<div class="line"><a id="l00166" name="l00166"></a><span class="lineno"> 166</span> </div>
<div class="line"><a id="l00167" name="l00167"></a><span class="lineno"> 167</span><span class="preprocessor">#else </span><span class="comment">/* APR_PROC_MUTEX_IS_GLOBAL */</span><span class="preprocessor"></span></div>
<div class="line"><a id="l00168" name="l00168"></a><span class="lineno"> 168</span> </div>
<div class="line"><a id="l00169" name="l00169"></a><span class="lineno"> 169</span><span class="comment">/* Some platforms [e.g. Win32] have cross process locks that are truly</span></div>
<div class="line"><a id="l00170" name="l00170"></a><span class="lineno"> 170</span><span class="comment"> * global locks, since there isn't the concept of cross-process locks.</span></div>
<div class="line"><a id="l00171" name="l00171"></a><span class="lineno"> 171</span><span class="comment"> * Define these platforms in terms of an apr_proc_mutex_t.</span></div>
<div class="line"><a id="l00172" name="l00172"></a><span class="lineno"> 172</span><span class="comment"> */</span></div>
<div class="line"><a id="l00173" name="l00173"></a><span class="lineno"> 173</span> </div>
<div class="line"><a id="l00174" name="l00174"></a><span class="lineno"> 174</span><span class="preprocessor">#define apr_global_mutex_t apr_proc_mutex_t</span></div>
<div class="line"><a id="l00175" name="l00175"></a><span class="lineno"> 175</span><span class="preprocessor">#define apr_global_mutex_create apr_proc_mutex_create</span></div>
<div class="line"><a id="l00176" name="l00176"></a><span class="lineno"> 176</span><span class="preprocessor">#define apr_global_mutex_child_init apr_proc_mutex_child_init</span></div>
<div class="line"><a id="l00177" name="l00177"></a><span class="lineno"> 177</span><span class="preprocessor">#define apr_global_mutex_lock apr_proc_mutex_lock</span></div>
<div class="line"><a id="l00178" name="l00178"></a><span class="lineno"> 178</span><span class="preprocessor">#define apr_global_mutex_trylock apr_proc_mutex_trylock</span></div>
<div class="line"><a id="l00179" name="l00179"></a><span class="lineno"> 179</span><span class="preprocessor">#define apr_global_mutex_unlock apr_proc_mutex_unlock</span></div>
<div class="line"><a id="l00180" name="l00180"></a><span class="lineno"> 180</span><span class="preprocessor">#define apr_global_mutex_destroy apr_proc_mutex_destroy</span></div>
<div class="line"><a id="l00181" name="l00181"></a><span class="lineno"> 181</span><span class="preprocessor">#define apr_global_mutex_lockfile apr_proc_mutex_lockfile</span></div>
<div class="line"><a id="l00182" name="l00182"></a><span class="lineno"> 182</span><span class="preprocessor">#define apr_global_mutex_mech apr_proc_mutex_mech</span></div>
<div class="line"><a id="l00183" name="l00183"></a><span class="lineno"> 183</span><span class="preprocessor">#define apr_global_mutex_name apr_proc_mutex_name</span></div>
<div class="line"><a id="l00184" name="l00184"></a><span class="lineno"> 184</span><span class="preprocessor">#define apr_global_mutex_perms_set apr_proc_mutex_perms_set</span></div>
<div class="line"><a id="l00185" name="l00185"></a><span class="lineno"> 185</span><span class="preprocessor">#define apr_global_mutex_pool_get apr_proc_mutex_pool_get</span></div>
<div class="line"><a id="l00186" name="l00186"></a><span class="lineno"> 186</span> </div>
<div class="line"><a id="l00187" name="l00187"></a><span class="lineno"> 187</span><span class="preprocessor">#endif</span></div>
<div class="line"><a id="l00188" name="l00188"></a><span class="lineno"> 188</span><span class="comment"></span> </div>
<div class="line"><a id="l00189" name="l00189"></a><span class="lineno"> 189</span><span class="comment">/** @} */</span></div>
<div class="line"><a id="l00190" name="l00190"></a><span class="lineno"> 190</span> </div>
<div class="line"><a id="l00191" name="l00191"></a><span class="lineno"> 191</span><span class="preprocessor">#ifdef __cplusplus</span></div>
<div class="line"><a id="l00192" name="l00192"></a><span class="lineno"> 192</span>}</div>
<div class="line"><a id="l00193" name="l00193"></a><span class="lineno"> 193</span><span class="preprocessor">#endif</span></div>
<div class="line"><a id="l00194" name="l00194"></a><span class="lineno"> 194</span> </div>
<div class="line"><a id="l00195" name="l00195"></a><span class="lineno"> 195</span><span class="preprocessor">#endif </span><span class="comment">/* ndef APR_GLOBAL_MUTEX_H */</span><span class="preprocessor"></span></div>
<div class="ttc" id="aapr_8h_html"><div class="ttname"><a href="apr_8h.html">apr.h</a></div><div class="ttdoc">APR Platform Definitions.</div></div>
<div class="ttc" id="aapr__errno_8h_html"><div class="ttname"><a href="apr__errno_8h.html">apr_errno.h</a></div><div class="ttdoc">APR Error Codes.</div></div>
<div class="ttc" id="aapr__pools_8h_html"><div class="ttname"><a href="apr__pools_8h.html">apr_pools.h</a></div><div class="ttdoc">APR memory allocation.</div></div>
<div class="ttc" id="aapr__proc__mutex_8h_html"><div class="ttname"><a href="apr__proc__mutex_8h.html">apr_proc_mutex.h</a></div><div class="ttdoc">APR Process Locking Routines.</div></div>
<div class="ttc" id="aapr__time_8h_html"><div class="ttname"><a href="apr__time_8h.html">apr_time.h</a></div><div class="ttdoc">APR Time Library.</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_ga1338485664e6c2737340114cace57121"><div class="ttname"><a href="group___a_p_r___global_mutex.html#ga1338485664e6c2737340114cace57121">apr_global_mutex_lock</a></div><div class="ttdeci">apr_status_t apr_global_mutex_lock(apr_global_mutex_t *mutex)</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_ga16e732ae76dfe104b157e0fc543d3aa3"><div class="ttname"><a href="group___a_p_r___global_mutex.html#ga16e732ae76dfe104b157e0fc543d3aa3">apr_global_mutex_unlock</a></div><div class="ttdeci">apr_status_t apr_global_mutex_unlock(apr_global_mutex_t *mutex)</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_ga1f2cb4a1ec57089db49701e747892607"><div class="ttname"><a href="group___a_p_r___global_mutex.html#ga1f2cb4a1ec57089db49701e747892607">apr_global_mutex_destroy</a></div><div class="ttdeci">apr_status_t apr_global_mutex_destroy(apr_global_mutex_t *mutex)</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_ga2a6543fba6473b47e33a7b7fc2ba6935"><div class="ttname"><a href="group___a_p_r___global_mutex.html#ga2a6543fba6473b47e33a7b7fc2ba6935">apr_global_mutex_trylock</a></div><div class="ttdeci">apr_status_t apr_global_mutex_trylock(apr_global_mutex_t *mutex)</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_ga3fc7dc5b076533ee566aa4888ac35ee7"><div class="ttname"><a href="group___a_p_r___global_mutex.html#ga3fc7dc5b076533ee566aa4888ac35ee7">apr_global_mutex_t</a></div><div class="ttdeci">struct apr_global_mutex_t apr_global_mutex_t</div><div class="ttdef"><b>Definition</b> apr_global_mutex.h:47</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_ga51eb034bca0352075c92c08a21d4d7a0"><div class="ttname"><a href="group___a_p_r___global_mutex.html#ga51eb034bca0352075c92c08a21d4d7a0">apr_global_mutex_child_init</a></div><div class="ttdeci">apr_status_t apr_global_mutex_child_init(apr_global_mutex_t **mutex, const char *fname, apr_pool_t *pool)</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_ga7a5ade1ba8ea6c7a7a61e3e719683cb0"><div class="ttname"><a href="group___a_p_r___global_mutex.html#ga7a5ade1ba8ea6c7a7a61e3e719683cb0">apr_global_mutex_create</a></div><div class="ttdeci">apr_status_t apr_global_mutex_create(apr_global_mutex_t **mutex, const char *fname, apr_lockmech_e mech, apr_pool_t *pool)</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_ga812b48b7afac2976a148fd16f4ede2de"><div class="ttname"><a href="group___a_p_r___global_mutex.html#ga812b48b7afac2976a148fd16f4ede2de">apr_global_mutex_mech</a></div><div class="ttdeci">apr_lockmech_e apr_global_mutex_mech(apr_global_mutex_t *mutex)</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_gabaecd41419208b84ae3b3b6fe402f51e"><div class="ttname"><a href="group___a_p_r___global_mutex.html#gabaecd41419208b84ae3b3b6fe402f51e">apr_global_mutex_lockfile</a></div><div class="ttdeci">const char * apr_global_mutex_lockfile(apr_global_mutex_t *mutex)</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_gae4d4ae9454c19bc58c56b69f42edfe8a"><div class="ttname"><a href="group___a_p_r___global_mutex.html#gae4d4ae9454c19bc58c56b69f42edfe8a">apr_global_mutex_timedlock</a></div><div class="ttdeci">apr_status_t apr_global_mutex_timedlock(apr_global_mutex_t *mutex, apr_interval_time_t timeout)</div></div>
<div class="ttc" id="agroup___a_p_r___global_mutex_html_gaef62790d34a253c63bb2e8bbe5a6a802"><div class="ttname"><a href="group___a_p_r___global_mutex.html#gaef62790d34a253c63bb2e8bbe5a6a802">apr_global_mutex_name</a></div><div class="ttdeci">const char * apr_global_mutex_name(apr_global_mutex_t *mutex)</div></div>
<div class="ttc" id="agroup__apr__errno_html_gaf76ee4543247e9fb3f3546203e590a6c"><div class="ttname"><a href="group__apr__errno.html#gaf76ee4543247e9fb3f3546203e590a6c">apr_status_t</a></div><div class="ttdeci">int apr_status_t</div><div class="ttdef"><b>Definition</b> apr_errno.h:44</div></div>
<div class="ttc" id="agroup__apr__platform_html_gad7b91b811a172bfa802603c2fb688f98"><div class="ttname"><a href="group__apr__platform.html#gad7b91b811a172bfa802603c2fb688f98">APR_DECLARE</a></div><div class="ttdeci">#define APR_DECLARE(type)</div><div class="ttdef"><b>Definition</b> apr.h:498</div></div>
<div class="ttc" id="agroup__apr__pools_html_ga89ce1d55c7f0c39ea87c88eabd655394"><div class="ttname"><a href="group__apr__pools.html#ga89ce1d55c7f0c39ea87c88eabd655394">APR_POOL_DECLARE_ACCESSOR</a></div><div class="ttdeci">#define APR_POOL_DECLARE_ACCESSOR(type)</div><div class="ttdef"><b>Definition</b> apr_pools.h:81</div></div>
<div class="ttc" id="agroup__apr__pools_html_gaf137f28edcf9a086cd6bc36c20d7cdfb"><div class="ttname"><a href="group__apr__pools.html#gaf137f28edcf9a086cd6bc36c20d7cdfb">apr_pool_t</a></div><div class="ttdeci">struct apr_pool_t apr_pool_t</div><div class="ttdef"><b>Definition</b> apr_pools.h:60</div></div>
<div class="ttc" id="agroup__apr__proc__mutex_html_ga75dd95a48a1e855a87b509b522746ed4"><div class="ttname"><a href="group__apr__proc__mutex.html#ga75dd95a48a1e855a87b509b522746ed4">apr_lockmech_e</a></div><div class="ttdeci">apr_lockmech_e</div><div class="ttdef"><b>Definition</b> apr_proc_mutex.h:46</div></div>
<div class="ttc" id="agroup__apr__time_html_gaae2129185a395cc393f76fabf4f43e47"><div class="ttname"><a href="group__apr__time.html#gaae2129185a395cc393f76fabf4f43e47">apr_interval_time_t</a></div><div class="ttdeci">apr_int64_t apr_interval_time_t</div><div class="ttdef"><b>Definition</b> apr_time.h:55</div></div>
</div><!-- fragment --></div><!-- contents -->
<!-- start footer part -->
<hr class="footer"/><address class="footer"><small>
Generated by <a href="https://www.doxygen.org/index.html"><img class="footer" src="doxygen.svg" width="104" height="31" alt="doxygen"/></a> 1.9.8
</small></address>
</body>
</html>